@@ -16,7 +16,7 @@ use POE::Component::IRC::Plugin::Whois;
 use Socket;
 use base qw(POE::Component::Pluggable);
 
-our $VERSION = '6.12';
+our $VERSION = '6.14';
 our ($GOT_SSL, $GOT_CLIENT_DNS, $GOT_SOCKET6, $GOT_ZLIB);
 
 BEGIN {
@@ -388,7 +388,7 @@ sub _sock_up {
     $self->{localaddr} = $localaddr;
 
     if ( $self->{socks_proxy} ) {
-        $self->{socket} = new POE::Wheel::ReadWrite(
+        $self->{socket} = POE::Wheel::ReadWrite->new(
             Handle       => $socket,
             Driver       => POE::Driver::SysRW->new(),
             Filter       => POE::Filter::Stream->new(),
@@ -438,7 +438,7 @@ sub _sock_up {
     }
     
     # Create a new ReadWrite wheel for the connected socket.
-    $self->{socket} = new POE::Wheel::ReadWrite(
+    $self->{socket} = POE::Wheel::ReadWrite->new(
         Handle       => $socket,
         Driver       => POE::Driver::SysRW->new(),
         InputFilter  => $self->{srv_filter},
@@ -1040,6 +1040,7 @@ sub onlytwoargs {
 sub privandnotice {
     my ($kernel, $state, $to) = @_[KERNEL, STATE, ARG0];
     my $message = join ' ', @_[ARG1 .. $#_];
+    my @messages = split /\n/, $message;
     my $pri = $_[OBJECT]->{IRC_CMDS}->{$state}->[CMD_PRI];
 
     $state =~ s/privmsglo/privmsg/;
@@ -1054,8 +1055,10 @@ sub privandnotice {
 
     $to = join ',', @$to if ref $to eq 'ARRAY';
     $state = uc $state;
-    $state .= " $to :$message";
-    $kernel->yield(sl_prioritized => $pri, $state);
+
+    for my $msg (@messages) {
+        $kernel->yield(sl_prioritized => $pri, "$state $to :$msg");
+    }
     return;
 }
 
@@ -1215,6 +1218,9 @@ sub sl_prioritized {
     if (bytes::length($msg) > $self->{msg_length} - bytes::length($self->nick_name())) {
         $msg = bytes::substr($msg, 0, $self->{msg_length} - bytes::length($self->nick_name()));
     }
+
+    # if we find a newline in the message, take that to be the end of it
+    $msg =~ s/\n.*//gm;
     
     if (@{ $self->{send_queue} }) {
         my $i = @{ $self->{send_queue} };
@@ -1437,7 +1443,7 @@ sub _delay {
     return if !defined $time;
     my $event = shift @{ $arrayref };
     my $alarm_id = $kernel->delay_set( $event => $time => @{ $arrayref } );
-    $self->send_event(irc_delay_set => $alarm_id, $event, @{ $arrayref } ) if $alarm_id;
+    $self->_send_event(irc_delay_set => $alarm_id, $event, @{ $arrayref } ) if $alarm_id;
     return $alarm_id;
 }
 
@@ -1454,7 +1460,7 @@ sub _delay_remove {
     my @old_alarm_list = $kernel->alarm_remove( $alarm_id );
     if (@old_alarm_list) {
         splice @old_alarm_list, 1, 1;
-        $self->send_event(irc_delay_removed => $alarm_id, @old_alarm_list );
+        $self->_send_event(irc_delay_removed => $alarm_id, @old_alarm_list );
         return \@old_alarm_list;
     }
     
@@ -1792,7 +1798,9 @@ L<C<register>|/"register"> and L<C<irc_registered>|/"irc_registered">.
 
 =head2 C<spawn>
 
-Takes a number of arguments, all of which are optional: 
+Takes a number of arguments, all of which are optional. All the options
+below may be supplied to the L<C<connect>|/"connect"> input event as well,
+except for B<'alias'>, B<'options'>, B<'NoDNS'>, and B<'plugin_debug'>.
 
 B<'alias'>, a name (kernel alias) that this instance will be known by;
 
@@ -1862,9 +1870,6 @@ B<'useipv6'>, enable the use of IPv6 for connections.
 C<spawn> will supply reasonable defaults for any of these attributes which are
 missing, so don't feel obliged to write them all out.
 
-All the above options may be supplied to L<C<connect>|/"connect"> input
-event as well.
-
 If the component finds that L<POE::Component::Client::DNS|POE::Component::Client::DNS>
 is installed it will use that to resolve the server name passed. Disable this
 behaviour if you like, by passing: C<< NoDNS => 1 >>.
@@ -2183,7 +2188,8 @@ it will be treated as a PART message and dealt with accordingly.
 Sends a public or private message to the nick(s) or channel(s) which
 you specify. Takes 2 arguments: the nick or channel to send a message
 to (use an array reference here to specify multiple recipients), and
-the text of the message to send.
+the text of the message to send. If the message contains newlines, it
+will be split up into multiple messages.
 
 Have a look at the constants in
 L<POE::Component::IRC::Common|POE::Component::IRC::Common> if you would
